/*! @heap-code/singleton v1.1.0 | License: MIT | Page: https://github.com/heap-code/singleton | Date: 2023-06-26 */
(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory();
	else if(typeof define === 'function' && define.amd)
		define([], factory);
	else {
		var a = factory();
		for(var i in a) (typeof exports === 'object' ? exports : root)[i] = a[i];
	}
})(self, () => {
return /******/ (() => { // webpackBootstrap
/******/ 	"use strict";
/******/ 	var __webpack_modules__ = ({

/***/ 465:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", ({ value: true }));
__exportStar(__webpack_require__(748), exports);


/***/ }),

/***/ 748:
/***/ ((__unused_webpack_module, exports) => {


Object.defineProperty(exports, "__esModule", ({ value: true }));
exports.Singleton = void 0;
/**
 * A (lazy) Singleton class that will store a single value.
 * The value will only be loaded when asked (lazy).
 *
 * It also works with promised values as they are only fulfilled once.
 *
 * @see {@link https://en.wikipedia.org/wiki/Singleton_pattern}
 */
var Singleton = /** @class */ (function () {
    /**
     * Creates a Singleton
     *
     * @param loader The function called to load the singleton value
     */
    function Singleton(loader) {
        this.loader = loader;
        /**
         * Has the Singleton been called ?
         */
        this.called = false;
    }
    Object.defineProperty(Singleton.prototype, "hasBeenCalled", {
        /**
         * @returns If the Singleton loader has been called
         */
        get: function () {
            return this.called;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Runs the loader if it has not already been called, then returns the value.
     * Only returns the value if it has already been called
     *
     * @returns The value of this singleton
     */
    Singleton.prototype.get = function () {
        if (!this.called) {
            this.called = true;
            this.value = this.loader();
        }
        return this.value;
    };
    return Singleton;
}());
exports.Singleton = Singleton;


/***/ })

/******/ 	});
/************************************************************************/
/******/ 	// The module cache
/******/ 	var __webpack_module_cache__ = {};
/******/ 	
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/ 		// Check if module is in cache
/******/ 		var cachedModule = __webpack_module_cache__[moduleId];
/******/ 		if (cachedModule !== undefined) {
/******/ 			return cachedModule.exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = __webpack_module_cache__[moduleId] = {
/******/ 			// no module.id needed
/******/ 			// no module.loaded needed
/******/ 			exports: {}
/******/ 		};
/******/ 	
/******/ 		// Execute the module function
/******/ 		__webpack_modules__[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/ 	
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/ 	
/************************************************************************/
/******/ 	
/******/ 	// startup
/******/ 	// Load entry module and return exports
/******/ 	// This entry module is referenced by other modules so it can't be inlined
/******/ 	var __webpack_exports__ = __webpack_require__(465);
/******/ 	
/******/ 	return __webpack_exports__;
/******/ })()
;
});
//# sourceMappingURL=singleton.umd.js.map